4.46. umbra.ui.nodes — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.46. umbra.ui.nodes

nodes.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the Application nodes classes.

Others:

## 4.46.1. Module Attributes

`umbra.ui.nodes.` `LOGGER`

## 4.46.2. Classes

class `umbra.ui.nodes.` `Mixin_GraphModelObject`

  Bases: `object`

  This class is a mixin used to bring common capabilities in Application Nodes classes.

  `roles`

    This method is the property for self.__roles attribute.

    Returns: | self.__roles. ( Dictionary )

  `flags`

    This method is the property for self.__flags attribute.

    Returns: | self.__flags. ( Integer )

  `triggerModel`

    This method is the property for self.__triggerModel attribute.

    Returns: | self.__triggerModel. ( Boolean )

class `umbra.ui.nodes.` `GraphModelAttribute`(name=None, value=None, roles=None, flags=None, **kwargs)

  Bases: `foundations.nodes.Attribute`, `umbra.ui.nodes.Mixin_GraphModelObject`

  This class represents a storage object for the `GraphModelNode` class attributes.

  Parameters: | name – Attribute name. ( String ) value – Attribute value. ( Object ) roles – Roles. ( Dictionary ) flags – Flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

  `attributeChanged`()

    This method triggers the host model(s) `umbra.ui.models.GraphModel.attributeChanged()` method.

    Returns: | Method success. ( Boolean )

class `umbra.ui.nodes.` `GraphModelNode`(name=None, parent=None, children=None, roles=None, flags=None, **kwargs)

  Bases: `foundations.nodes.AbstractCompositeNode`, `umbra.ui.nodes.Mixin_GraphModelObject`

  This class defines `GraphModel` class base Node object.

  Parameters: | name – Node name. ( String ) parent – Node parent. ( AbstractNode / AbstractCompositeNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) flags – Flags. ( Qt.ItemFlag ) **kwargs – Keywords arguments. ( ** )

  `nodeChanged`()

    This method triggers the host model(s) `umbra.ui.models.GraphModel.nodeChanged()` method.

    Returns: | Method success. ( Boolean )

class `umbra.ui.nodes.` `DefaultNode`(name=None, parent=None, children=None, **kwargs)

  Bases: `foundations.nodes.AbstractCompositeNode`

  This class defines the default Node used in `GraphModel` class model.
  This simple Node is used as an invisible root Node for `GraphModel` class models.

  Parameters: | name – Node name. ( String ) parent – Node parent. ( AbstractCompositeNode ) children – Children. ( List ) **kwargs – Keywords arguments. ( ** )

class `umbra.ui.nodes.` `FormatNode`(name=None, parent=None, children=None, format=None, **kwargs)

  Bases: `foundations.nodes.AbstractCompositeNode`

  This class defines the format base Node object.

  Parameters: | name – Node name. ( String ) parent – Node parent. ( AbstractNode / AbstractCompositeNode ) children – Children. ( List ) format – Format. ( Object ) **kwargs – Keywords arguments. ( ** )

  `format`

    This method is the property for self.__format attribute.

    Returns: | self.__format. ( Object )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »